import { world, EquipmentSlot, EntityEquippableComponent } from "@minecraft/server";

// Define block loot table mapping for sheared drops
const blockLootTables = {
    "biomes_and_beyond:aspen_leaves": '"blocks/aspen_leaves_sheared"',
    "biomes_and_beyond:redwood_leaves": '"blocks/redwood_leaves_sheared"',
    "biomes_and_beyond:autumn_leaves": '"blocks/autumn_leaves_sheared"',
    "biomes_and_beyond:jacaramda_leaves": '"blocks/jacaramda_leaves_sheared"',
    "biomes_and_beyond:maple_leaves": '"blocks/maple_leaves_sheared"',
    "biomes_and_beyond:maple_yellow_leaves": '"blocks/yellow_maple_leaves_sheared"',
    "biomes_and_beyond:baobab_leaves": '"blocks/baobab_leaves_sheared"',
    "biomes_and_beyond:fir_leaves": '"blocks/fir_leaves_sheared"',
    "biomes_and_beyond:forsaken_oak_leaves": '"blocks/forsaken_oak_leaves_sheared"',
    "biomes_and_beyond:chorus_leaves": '"blocks/chorus_leaves_sheared"',
    "biomes_and_beyond:chorus_leaves_popped": '"blocks/chorus_leaves_popped_sheared"'
};

// Special blocks like barley with different loot for normal and sheared
const specialShearBlocks = {
    "biomes_and_beyond:barley_bottom": {
        normal: '"blocks/barley"',
        sheared: '"blocks/barley_sheared"'
    },
    "biomes_and_beyond:barley_top": {
        normal: '"blocks/barley"',
        sheared: '"blocks/barley_sheared"'
    }
    // Add more special blocks here
};

// Subscribe to the playerBreakBlock event
world.afterEvents.playerBreakBlock.subscribe(({ brokenBlockPermutation, player, block }) => {
    const blockTypeId = brokenBlockPermutation.type.id;
    const mainhand = player.getComponent(EntityEquippableComponent.componentId)?.getEquipmentSlot(EquipmentSlot.Mainhand);
    const heldItem = mainhand?.getItem();
    const blockLocation = block.location;

    // Handle special blocks like barley
    if (specialShearBlocks[blockTypeId]) {
        if (heldItem && heldItem.typeId === "minecraft:shears") {
            // Drop sheared loot table
            player.runCommand(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot ${specialShearBlocks[blockTypeId].sheared}`);
        } else {
            // Drop normal loot table (barley bundle)
            player.runCommand(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot ${specialShearBlocks[blockTypeId].normal}`);
        }
        return;
    }

    // Handle regular sheared blocks
    if (heldItem && heldItem.typeId === "minecraft:shears" && blockLootTables[blockTypeId]) {
        const lootTable = blockLootTables[blockTypeId];
        player.runCommand(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot ${lootTable}`);
    }
});
