import { world, BlockPermutation } from "@minecraft/server";

// Standard double plants
const tallBottomFlowers = [
    { id: "biomes_and_beyond:deadfern_bottom", topBit: { id: "biomes_and_beyond:deadfern_top" } },
    { id: "biomes_and_beyond:cattail_bottom", topBit: { id: "biomes_and_beyond:cattail_top" } },
    { id: "biomes_and_beyond:jungfern_bottom", topBit: { id: "biomes_and_beyond:jungfern_top" } },
    { id: "biomes_and_beyond:mullein_bottom", topBit: { id: "biomes_and_beyond:mullein_top" } },
    { id: "biomes_and_beyond:void_blossom_bush_bottom", topBit: { id: "biomes_and_beyond:void_blossom_bush_top" } }
];

// Special double plants with custom logic (e.g., random growth)
const specialDoublePlants = [
    {
        id: "biomes_and_beyond:barley_bottom",
        topBit: {
            id: "biomes_and_beyond:barley_top",
            randomGrowth: true, // Custom flag for random growth
            growthState: [0, 1, 2] // Possible growth values
        }
    }
    // Add more 
];

world.afterEvents.playerPlaceBlock.subscribe(ev => {
    const above = ev.block.above();

    // Check for special double plants first
    const matchingSpecial = specialDoublePlants.find(flower => ev.block.permutation.matches(flower.id));
    if (matchingSpecial && above.isAir) {
        const top = matchingSpecial.topBit;
        let growth = 0;
        if (top.randomGrowth && Array.isArray(top.growthState)) {
            growth = top.growthState[Math.floor(Math.random() * top.growthState.length)];
        }
        above.setPermutation(BlockPermutation.resolve(top.id, { "biomes_and_beyond:length": growth }));
        return;
    }

    // Standard double plants
    const matchingBottomFlower = tallBottomFlowers.find(flower => ev.block.permutation.matches(flower.id));
    if (matchingBottomFlower && above.isAir) {
        above.setPermutation(BlockPermutation.resolve(matchingBottomFlower.topBit.id));
    } else if ((matchingSpecial || matchingBottomFlower) && !above.isAir) {
        // If the above block is not air, break the placed bottom block
        const { x, y, z } = ev.block.location;
        ev.dimension.runCommand(`setblock ${x} ${y} ${z} air[] destroy`);
    }
});

world.afterEvents.playerBreakBlock.subscribe(ev => {
    // Check for special double plants
    const matchingSpecial = specialDoublePlants.find(flower => ev.brokenBlockPermutation.matches(flower.topBit.id));
    if (matchingSpecial) {
        const { x, y, z } = ev.block.location;
        ev.dimension.runCommand(`setblock ${x} ${y - 1} ${z} air[] destroy`);
        return;
    }

    // Standard double plants
    const matchingTopFlower = tallBottomFlowers.find(flower => ev.brokenBlockPermutation.matches(flower.topBit.id));
    if (matchingTopFlower) {
        const { x, y, z } = ev.block.location;
        ev.dimension.runCommand(`setblock ${x} ${y - 1} ${z} air[] destroy`);
    }
});
