import { Block } from "@minecraft/server";

// Returns true for any block with "fence" in the id (including gates)
function isFenceConnectable(block) {
    return (
        block &&
        typeof block.typeId === "string" &&
        block.typeId.toLowerCase().includes("fence")
    );
}

// Returns true only for your custom fences (not gates)
function isCustomFenceBlock(block) {
    return (
        block &&
        typeof block.typeId === "string" &&
        block.typeId.startsWith("biomes_and_beyond:") &&
        block.typeId.toLowerCase().includes("fence") &&
        !block.typeId.toLowerCase().includes("gate")
    );
}

export class fence_Manager {
    static update_Fence_States(Fence) {
        if (!isCustomFenceBlock(Fence)) return;

        let north = undefined;
        try { north = Fence.north(1); } catch { }
        let south = undefined;
        try { south = Fence.south(1); } catch { }
        let east = undefined;
        try { east = Fence.east(1); } catch { }
        let west = undefined;
        try { west = Fence.west(1); } catch { }
        const blocks = [
            { block: north, side: "north" },
            { block: south, side: "south" },
            { block: east, side: "east" },
            { block: west, side: "west" },
        ];
        for (const blockData of blocks) {
            if (isFenceConnectable(blockData.block)) {
                Fence.setPermutation(Fence.permutation.withState("biomes_and_beyond:" + blockData.side, true));
            } else {
                Fence.setPermutation(Fence.permutation.withState("biomes_and_beyond:" + blockData.side, false));
            }
        }
    }
    static updateFencesAround(Block) {
        let north = undefined;
        try { north = Block.north(1); } catch { }
        let south = undefined;
        try { south = Block.south(1); } catch { }
        let east = undefined;
        try { east = Block.east(1); } catch { }
        let west = undefined;
        try { west = Block.west(1); } catch { }
        const blocks = [Block, north, south, east, west];
        for (const block of blocks) {
            if (isCustomFenceBlock(block)) {
                this.update_Fence_States(block);
            }
        }
    }
}